const _ = require('lodash')
const prefixNegativeModifiers = (base, modifier) => {
  return _.startsWith(modifier, '-')
    ? `-${base}-${modifier.slice(1)}`
    : `${base}-${modifier}`
}

module.exports = function() {
  return function({ addUtilities, e, theme, variants }) {
    const generators = [
      (size, modifier) => ({
        [`.${e(prefixNegativeModifiers('p', modifier))}`]: {
          padding: `${size}`,
        },
      }),
      (size, modifier) => ({
        [`.${e(prefixNegativeModifiers('py', modifier))}`]: {
          'padding-block-start': `${size}`,
          'padding-block-end': `${size}`,
        },
        [`.${e(prefixNegativeModifiers('px', modifier))}`]: {
          'padding-inline-start': `${size}`,
          'padding-inline-end': `${size}`,
        },
      }),
      (size, modifier) => ({
        [`.${e(prefixNegativeModifiers('pbs', modifier))}`]: {
          'padding-block-start': `${size}`,
        },
        [`.${e(prefixNegativeModifiers('pie', modifier))}`]: {
          'padding-inline-end': `${size}`,
        },
        [`.${e(prefixNegativeModifiers('pbe', modifier))}`]: {
          'padding-block-end': `${size}`,
        },
        [`.${e(prefixNegativeModifiers('pis', modifier))}`]: {
          'padding-inline-start': `${size}`,
        },
      }),
    ]

    const utilities = _.flatMap(generators, generator => {
      return _.flatMap(theme('padding'), generator)
    })

    addUtilities(utilities, variants('padding'))
  }
}
